"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeUrlMapXDefaultRouteActionXCorsPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_CREDENTIALS_FIELD_NUMBER: builtins.int
    ALLOW_HEADERS_FIELD_NUMBER: builtins.int
    ALLOW_METHODS_FIELD_NUMBER: builtins.int
    ALLOW_ORIGIN_REGEXES_FIELD_NUMBER: builtins.int
    ALLOW_ORIGINS_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    EXPOSE_HEADERS_FIELD_NUMBER: builtins.int
    MAX_AGE_FIELD_NUMBER: builtins.int
    allow_credentials: builtins.bool
    @property
    def allow_headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def allow_methods(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def allow_origin_regexes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def allow_origins(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    disabled: builtins.bool
    @property
    def expose_headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    max_age: builtins.float
    def __init__(
        self,
        *,
        allow_credentials: builtins.bool = ...,
        allow_headers: collections.abc.Iterable[builtins.str] | None = ...,
        allow_methods: collections.abc.Iterable[builtins.str] | None = ...,
        allow_origin_regexes: collections.abc.Iterable[builtins.str] | None = ...,
        allow_origins: collections.abc.Iterable[builtins.str] | None = ...,
        disabled: builtins.bool = ...,
        expose_headers: collections.abc.Iterable[builtins.str] | None = ...,
        max_age: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_credentials", b"allow_credentials", "allow_headers", b"allow_headers", "allow_methods", b"allow_methods", "allow_origin_regexes", b"allow_origin_regexes", "allow_origins", b"allow_origins", "disabled", b"disabled", "expose_headers", b"expose_headers", "max_age", b"max_age"]) -> None: ...

global___ComputeUrlMapXDefaultRouteActionXCorsPolicy = ComputeUrlMapXDefaultRouteActionXCorsPolicy

@typing_extensions.final
class ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicyXAbort(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_STATUS_FIELD_NUMBER: builtins.int
    PERCENTAGE_FIELD_NUMBER: builtins.int
    http_status: builtins.float
    percentage: builtins.float
    def __init__(
        self,
        *,
        http_status: builtins.float = ...,
        percentage: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["http_status", b"http_status", "percentage", b"percentage"]) -> None: ...

global___ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicyXAbort = ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicyXAbort

@typing_extensions.final
class ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicyXDelayXFixedDelay(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NANOS_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    nanos: builtins.float
    seconds: builtins.str
    def __init__(
        self,
        *,
        nanos: builtins.float = ...,
        seconds: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nanos", b"nanos", "seconds", b"seconds"]) -> None: ...

global___ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicyXDelayXFixedDelay = ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicyXDelayXFixedDelay

@typing_extensions.final
class ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicyXDelay(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PERCENTAGE_FIELD_NUMBER: builtins.int
    FIXED_DELAY_FIELD_NUMBER: builtins.int
    percentage: builtins.float
    @property
    def fixed_delay(self) -> global___ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicyXDelayXFixedDelay: ...
    def __init__(
        self,
        *,
        percentage: builtins.float = ...,
        fixed_delay: global___ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicyXDelayXFixedDelay | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fixed_delay", b"fixed_delay"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fixed_delay", b"fixed_delay", "percentage", b"percentage"]) -> None: ...

global___ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicyXDelay = ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicyXDelay

@typing_extensions.final
class ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ABORT_FIELD_NUMBER: builtins.int
    DELAY_FIELD_NUMBER: builtins.int
    @property
    def abort(self) -> global___ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicyXAbort: ...
    @property
    def delay(self) -> global___ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicyXDelay: ...
    def __init__(
        self,
        *,
        abort: global___ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicyXAbort | None = ...,
        delay: global___ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicyXDelay | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["abort", b"abort", "delay", b"delay"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["abort", b"abort", "delay", b"delay"]) -> None: ...

global___ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicy = ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicy

@typing_extensions.final
class ComputeUrlMapXDefaultRouteActionXRequestMirrorPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_SERVICE_FIELD_NUMBER: builtins.int
    backend_service: builtins.str
    def __init__(
        self,
        *,
        backend_service: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["backend_service", b"backend_service"]) -> None: ...

global___ComputeUrlMapXDefaultRouteActionXRequestMirrorPolicy = ComputeUrlMapXDefaultRouteActionXRequestMirrorPolicy

@typing_extensions.final
class ComputeUrlMapXDefaultRouteActionXRetryPolicyXPerTryTimeout(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NANOS_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    nanos: builtins.float
    seconds: builtins.str
    def __init__(
        self,
        *,
        nanos: builtins.float = ...,
        seconds: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nanos", b"nanos", "seconds", b"seconds"]) -> None: ...

global___ComputeUrlMapXDefaultRouteActionXRetryPolicyXPerTryTimeout = ComputeUrlMapXDefaultRouteActionXRetryPolicyXPerTryTimeout

@typing_extensions.final
class ComputeUrlMapXDefaultRouteActionXRetryPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUM_RETRIES_FIELD_NUMBER: builtins.int
    RETRY_CONDITIONS_FIELD_NUMBER: builtins.int
    PER_TRY_TIMEOUT_FIELD_NUMBER: builtins.int
    num_retries: builtins.float
    @property
    def retry_conditions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def per_try_timeout(self) -> global___ComputeUrlMapXDefaultRouteActionXRetryPolicyXPerTryTimeout: ...
    def __init__(
        self,
        *,
        num_retries: builtins.float = ...,
        retry_conditions: collections.abc.Iterable[builtins.str] | None = ...,
        per_try_timeout: global___ComputeUrlMapXDefaultRouteActionXRetryPolicyXPerTryTimeout | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["per_try_timeout", b"per_try_timeout"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["num_retries", b"num_retries", "per_try_timeout", b"per_try_timeout", "retry_conditions", b"retry_conditions"]) -> None: ...

global___ComputeUrlMapXDefaultRouteActionXRetryPolicy = ComputeUrlMapXDefaultRouteActionXRetryPolicy

@typing_extensions.final
class ComputeUrlMapXDefaultRouteActionXTimeout(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NANOS_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    nanos: builtins.float
    seconds: builtins.str
    def __init__(
        self,
        *,
        nanos: builtins.float = ...,
        seconds: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nanos", b"nanos", "seconds", b"seconds"]) -> None: ...

global___ComputeUrlMapXDefaultRouteActionXTimeout = ComputeUrlMapXDefaultRouteActionXTimeout

@typing_extensions.final
class ComputeUrlMapXDefaultRouteActionXUrlRewrite(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REWRITE_FIELD_NUMBER: builtins.int
    PATH_PREFIX_REWRITE_FIELD_NUMBER: builtins.int
    host_rewrite: builtins.str
    path_prefix_rewrite: builtins.str
    def __init__(
        self,
        *,
        host_rewrite: builtins.str = ...,
        path_prefix_rewrite: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host_rewrite", b"host_rewrite", "path_prefix_rewrite", b"path_prefix_rewrite"]) -> None: ...

global___ComputeUrlMapXDefaultRouteActionXUrlRewrite = ComputeUrlMapXDefaultRouteActionXUrlRewrite

@typing_extensions.final
class ComputeUrlMapXDefaultRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_NAME_FIELD_NUMBER: builtins.int
    HEADER_VALUE_FIELD_NUMBER: builtins.int
    REPLACE_FIELD_NUMBER: builtins.int
    header_name: builtins.str
    header_value: builtins.str
    replace: builtins.bool
    def __init__(
        self,
        *,
        header_name: builtins.str = ...,
        header_value: builtins.str = ...,
        replace: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["header_name", b"header_name", "header_value", b"header_value", "replace", b"replace"]) -> None: ...

global___ComputeUrlMapXDefaultRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd = ComputeUrlMapXDefaultRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd

@typing_extensions.final
class ComputeUrlMapXDefaultRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_NAME_FIELD_NUMBER: builtins.int
    HEADER_VALUE_FIELD_NUMBER: builtins.int
    REPLACE_FIELD_NUMBER: builtins.int
    header_name: builtins.str
    header_value: builtins.str
    replace: builtins.bool
    def __init__(
        self,
        *,
        header_name: builtins.str = ...,
        header_value: builtins.str = ...,
        replace: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["header_name", b"header_name", "header_value", b"header_value", "replace", b"replace"]) -> None: ...

global___ComputeUrlMapXDefaultRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd = ComputeUrlMapXDefaultRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd

@typing_extensions.final
class ComputeUrlMapXDefaultRouteActionXWeightedBackendServicesXHeaderAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_HEADERS_TO_REMOVE_FIELD_NUMBER: builtins.int
    RESPONSE_HEADERS_TO_REMOVE_FIELD_NUMBER: builtins.int
    REQUEST_HEADERS_TO_ADD_FIELD_NUMBER: builtins.int
    RESPONSE_HEADERS_TO_ADD_FIELD_NUMBER: builtins.int
    @property
    def request_headers_to_remove(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def response_headers_to_remove(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def request_headers_to_add(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeUrlMapXDefaultRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd]: ...
    @property
    def response_headers_to_add(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeUrlMapXDefaultRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd]: ...
    def __init__(
        self,
        *,
        request_headers_to_remove: collections.abc.Iterable[builtins.str] | None = ...,
        response_headers_to_remove: collections.abc.Iterable[builtins.str] | None = ...,
        request_headers_to_add: collections.abc.Iterable[global___ComputeUrlMapXDefaultRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd] | None = ...,
        response_headers_to_add: collections.abc.Iterable[global___ComputeUrlMapXDefaultRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["request_headers_to_add", b"request_headers_to_add", "request_headers_to_remove", b"request_headers_to_remove", "response_headers_to_add", b"response_headers_to_add", "response_headers_to_remove", b"response_headers_to_remove"]) -> None: ...

global___ComputeUrlMapXDefaultRouteActionXWeightedBackendServicesXHeaderAction = ComputeUrlMapXDefaultRouteActionXWeightedBackendServicesXHeaderAction

@typing_extensions.final
class ComputeUrlMapXDefaultRouteActionXWeightedBackendServices(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_SERVICE_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    HEADER_ACTION_FIELD_NUMBER: builtins.int
    backend_service: builtins.str
    weight: builtins.float
    @property
    def header_action(self) -> global___ComputeUrlMapXDefaultRouteActionXWeightedBackendServicesXHeaderAction: ...
    def __init__(
        self,
        *,
        backend_service: builtins.str = ...,
        weight: builtins.float = ...,
        header_action: global___ComputeUrlMapXDefaultRouteActionXWeightedBackendServicesXHeaderAction | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["header_action", b"header_action"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backend_service", b"backend_service", "header_action", b"header_action", "weight", b"weight"]) -> None: ...

global___ComputeUrlMapXDefaultRouteActionXWeightedBackendServices = ComputeUrlMapXDefaultRouteActionXWeightedBackendServices

@typing_extensions.final
class ComputeUrlMapXDefaultRouteAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CORS_POLICY_FIELD_NUMBER: builtins.int
    FAULT_INJECTION_POLICY_FIELD_NUMBER: builtins.int
    REQUEST_MIRROR_POLICY_FIELD_NUMBER: builtins.int
    RETRY_POLICY_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    URL_REWRITE_FIELD_NUMBER: builtins.int
    WEIGHTED_BACKEND_SERVICES_FIELD_NUMBER: builtins.int
    @property
    def cors_policy(self) -> global___ComputeUrlMapXDefaultRouteActionXCorsPolicy: ...
    @property
    def fault_injection_policy(self) -> global___ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicy: ...
    @property
    def request_mirror_policy(self) -> global___ComputeUrlMapXDefaultRouteActionXRequestMirrorPolicy: ...
    @property
    def retry_policy(self) -> global___ComputeUrlMapXDefaultRouteActionXRetryPolicy: ...
    @property
    def timeout(self) -> global___ComputeUrlMapXDefaultRouteActionXTimeout: ...
    @property
    def url_rewrite(self) -> global___ComputeUrlMapXDefaultRouteActionXUrlRewrite: ...
    @property
    def weighted_backend_services(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeUrlMapXDefaultRouteActionXWeightedBackendServices]: ...
    def __init__(
        self,
        *,
        cors_policy: global___ComputeUrlMapXDefaultRouteActionXCorsPolicy | None = ...,
        fault_injection_policy: global___ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicy | None = ...,
        request_mirror_policy: global___ComputeUrlMapXDefaultRouteActionXRequestMirrorPolicy | None = ...,
        retry_policy: global___ComputeUrlMapXDefaultRouteActionXRetryPolicy | None = ...,
        timeout: global___ComputeUrlMapXDefaultRouteActionXTimeout | None = ...,
        url_rewrite: global___ComputeUrlMapXDefaultRouteActionXUrlRewrite | None = ...,
        weighted_backend_services: collections.abc.Iterable[global___ComputeUrlMapXDefaultRouteActionXWeightedBackendServices] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cors_policy", b"cors_policy", "fault_injection_policy", b"fault_injection_policy", "request_mirror_policy", b"request_mirror_policy", "retry_policy", b"retry_policy", "timeout", b"timeout", "url_rewrite", b"url_rewrite"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cors_policy", b"cors_policy", "fault_injection_policy", b"fault_injection_policy", "request_mirror_policy", b"request_mirror_policy", "retry_policy", b"retry_policy", "timeout", b"timeout", "url_rewrite", b"url_rewrite", "weighted_backend_services", b"weighted_backend_services"]) -> None: ...

global___ComputeUrlMapXDefaultRouteAction = ComputeUrlMapXDefaultRouteAction

@typing_extensions.final
class ComputeUrlMapXDefaultUrlRedirect(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REDIRECT_FIELD_NUMBER: builtins.int
    HTTPS_REDIRECT_FIELD_NUMBER: builtins.int
    PATH_REDIRECT_FIELD_NUMBER: builtins.int
    PREFIX_REDIRECT_FIELD_NUMBER: builtins.int
    REDIRECT_RESPONSE_CODE_FIELD_NUMBER: builtins.int
    STRIP_QUERY_FIELD_NUMBER: builtins.int
    host_redirect: builtins.str
    https_redirect: builtins.bool
    path_redirect: builtins.str
    prefix_redirect: builtins.str
    redirect_response_code: builtins.str
    strip_query: builtins.bool
    def __init__(
        self,
        *,
        host_redirect: builtins.str = ...,
        https_redirect: builtins.bool = ...,
        path_redirect: builtins.str = ...,
        prefix_redirect: builtins.str = ...,
        redirect_response_code: builtins.str = ...,
        strip_query: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host_redirect", b"host_redirect", "https_redirect", b"https_redirect", "path_redirect", b"path_redirect", "prefix_redirect", b"prefix_redirect", "redirect_response_code", b"redirect_response_code", "strip_query", b"strip_query"]) -> None: ...

global___ComputeUrlMapXDefaultUrlRedirect = ComputeUrlMapXDefaultUrlRedirect

@typing_extensions.final
class ComputeUrlMapXHeaderActionXRequestHeadersToAdd(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_NAME_FIELD_NUMBER: builtins.int
    HEADER_VALUE_FIELD_NUMBER: builtins.int
    REPLACE_FIELD_NUMBER: builtins.int
    header_name: builtins.str
    header_value: builtins.str
    replace: builtins.bool
    def __init__(
        self,
        *,
        header_name: builtins.str = ...,
        header_value: builtins.str = ...,
        replace: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["header_name", b"header_name", "header_value", b"header_value", "replace", b"replace"]) -> None: ...

global___ComputeUrlMapXHeaderActionXRequestHeadersToAdd = ComputeUrlMapXHeaderActionXRequestHeadersToAdd

@typing_extensions.final
class ComputeUrlMapXHeaderActionXResponseHeadersToAdd(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_NAME_FIELD_NUMBER: builtins.int
    HEADER_VALUE_FIELD_NUMBER: builtins.int
    REPLACE_FIELD_NUMBER: builtins.int
    header_name: builtins.str
    header_value: builtins.str
    replace: builtins.bool
    def __init__(
        self,
        *,
        header_name: builtins.str = ...,
        header_value: builtins.str = ...,
        replace: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["header_name", b"header_name", "header_value", b"header_value", "replace", b"replace"]) -> None: ...

global___ComputeUrlMapXHeaderActionXResponseHeadersToAdd = ComputeUrlMapXHeaderActionXResponseHeadersToAdd

@typing_extensions.final
class ComputeUrlMapXHeaderAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_HEADERS_TO_REMOVE_FIELD_NUMBER: builtins.int
    RESPONSE_HEADERS_TO_REMOVE_FIELD_NUMBER: builtins.int
    REQUEST_HEADERS_TO_ADD_FIELD_NUMBER: builtins.int
    RESPONSE_HEADERS_TO_ADD_FIELD_NUMBER: builtins.int
    @property
    def request_headers_to_remove(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def response_headers_to_remove(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def request_headers_to_add(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeUrlMapXHeaderActionXRequestHeadersToAdd]: ...
    @property
    def response_headers_to_add(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeUrlMapXHeaderActionXResponseHeadersToAdd]: ...
    def __init__(
        self,
        *,
        request_headers_to_remove: collections.abc.Iterable[builtins.str] | None = ...,
        response_headers_to_remove: collections.abc.Iterable[builtins.str] | None = ...,
        request_headers_to_add: collections.abc.Iterable[global___ComputeUrlMapXHeaderActionXRequestHeadersToAdd] | None = ...,
        response_headers_to_add: collections.abc.Iterable[global___ComputeUrlMapXHeaderActionXResponseHeadersToAdd] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["request_headers_to_add", b"request_headers_to_add", "request_headers_to_remove", b"request_headers_to_remove", "response_headers_to_add", b"response_headers_to_add", "response_headers_to_remove", b"response_headers_to_remove"]) -> None: ...

global___ComputeUrlMapXHeaderAction = ComputeUrlMapXHeaderAction

@typing_extensions.final
class ComputeUrlMapXHostRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    HOSTS_FIELD_NUMBER: builtins.int
    PATH_MATCHER_FIELD_NUMBER: builtins.int
    description: builtins.str
    @property
    def hosts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    path_matcher: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        hosts: collections.abc.Iterable[builtins.str] | None = ...,
        path_matcher: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "hosts", b"hosts", "path_matcher", b"path_matcher"]) -> None: ...

global___ComputeUrlMapXHostRule = ComputeUrlMapXHostRule

@typing_extensions.final
class ComputeUrlMapXPathMatcherXDefaultRouteActionXCorsPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_CREDENTIALS_FIELD_NUMBER: builtins.int
    ALLOW_HEADERS_FIELD_NUMBER: builtins.int
    ALLOW_METHODS_FIELD_NUMBER: builtins.int
    ALLOW_ORIGIN_REGEXES_FIELD_NUMBER: builtins.int
    ALLOW_ORIGINS_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    EXPOSE_HEADERS_FIELD_NUMBER: builtins.int
    MAX_AGE_FIELD_NUMBER: builtins.int
    allow_credentials: builtins.bool
    @property
    def allow_headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def allow_methods(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def allow_origin_regexes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def allow_origins(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    disabled: builtins.bool
    @property
    def expose_headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    max_age: builtins.float
    def __init__(
        self,
        *,
        allow_credentials: builtins.bool = ...,
        allow_headers: collections.abc.Iterable[builtins.str] | None = ...,
        allow_methods: collections.abc.Iterable[builtins.str] | None = ...,
        allow_origin_regexes: collections.abc.Iterable[builtins.str] | None = ...,
        allow_origins: collections.abc.Iterable[builtins.str] | None = ...,
        disabled: builtins.bool = ...,
        expose_headers: collections.abc.Iterable[builtins.str] | None = ...,
        max_age: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_credentials", b"allow_credentials", "allow_headers", b"allow_headers", "allow_methods", b"allow_methods", "allow_origin_regexes", b"allow_origin_regexes", "allow_origins", b"allow_origins", "disabled", b"disabled", "expose_headers", b"expose_headers", "max_age", b"max_age"]) -> None: ...

global___ComputeUrlMapXPathMatcherXDefaultRouteActionXCorsPolicy = ComputeUrlMapXPathMatcherXDefaultRouteActionXCorsPolicy

@typing_extensions.final
class ComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicyXAbort(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_STATUS_FIELD_NUMBER: builtins.int
    PERCENTAGE_FIELD_NUMBER: builtins.int
    http_status: builtins.float
    percentage: builtins.float
    def __init__(
        self,
        *,
        http_status: builtins.float = ...,
        percentage: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["http_status", b"http_status", "percentage", b"percentage"]) -> None: ...

global___ComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicyXAbort = ComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicyXAbort

@typing_extensions.final
class ComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicyXDelayXFixedDelay(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NANOS_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    nanos: builtins.float
    seconds: builtins.str
    def __init__(
        self,
        *,
        nanos: builtins.float = ...,
        seconds: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nanos", b"nanos", "seconds", b"seconds"]) -> None: ...

global___ComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicyXDelayXFixedDelay = ComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicyXDelayXFixedDelay

@typing_extensions.final
class ComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicyXDelay(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PERCENTAGE_FIELD_NUMBER: builtins.int
    FIXED_DELAY_FIELD_NUMBER: builtins.int
    percentage: builtins.float
    @property
    def fixed_delay(self) -> global___ComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicyXDelayXFixedDelay: ...
    def __init__(
        self,
        *,
        percentage: builtins.float = ...,
        fixed_delay: global___ComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicyXDelayXFixedDelay | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fixed_delay", b"fixed_delay"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fixed_delay", b"fixed_delay", "percentage", b"percentage"]) -> None: ...

global___ComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicyXDelay = ComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicyXDelay

@typing_extensions.final
class ComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ABORT_FIELD_NUMBER: builtins.int
    DELAY_FIELD_NUMBER: builtins.int
    @property
    def abort(self) -> global___ComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicyXAbort: ...
    @property
    def delay(self) -> global___ComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicyXDelay: ...
    def __init__(
        self,
        *,
        abort: global___ComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicyXAbort | None = ...,
        delay: global___ComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicyXDelay | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["abort", b"abort", "delay", b"delay"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["abort", b"abort", "delay", b"delay"]) -> None: ...

global___ComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicy = ComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicy

@typing_extensions.final
class ComputeUrlMapXPathMatcherXDefaultRouteActionXRequestMirrorPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_SERVICE_FIELD_NUMBER: builtins.int
    backend_service: builtins.str
    def __init__(
        self,
        *,
        backend_service: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["backend_service", b"backend_service"]) -> None: ...

global___ComputeUrlMapXPathMatcherXDefaultRouteActionXRequestMirrorPolicy = ComputeUrlMapXPathMatcherXDefaultRouteActionXRequestMirrorPolicy

@typing_extensions.final
class ComputeUrlMapXPathMatcherXDefaultRouteActionXRetryPolicyXPerTryTimeout(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NANOS_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    nanos: builtins.float
    seconds: builtins.str
    def __init__(
        self,
        *,
        nanos: builtins.float = ...,
        seconds: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nanos", b"nanos", "seconds", b"seconds"]) -> None: ...

global___ComputeUrlMapXPathMatcherXDefaultRouteActionXRetryPolicyXPerTryTimeout = ComputeUrlMapXPathMatcherXDefaultRouteActionXRetryPolicyXPerTryTimeout

@typing_extensions.final
class ComputeUrlMapXPathMatcherXDefaultRouteActionXRetryPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUM_RETRIES_FIELD_NUMBER: builtins.int
    RETRY_CONDITIONS_FIELD_NUMBER: builtins.int
    PER_TRY_TIMEOUT_FIELD_NUMBER: builtins.int
    num_retries: builtins.float
    @property
    def retry_conditions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def per_try_timeout(self) -> global___ComputeUrlMapXPathMatcherXDefaultRouteActionXRetryPolicyXPerTryTimeout: ...
    def __init__(
        self,
        *,
        num_retries: builtins.float = ...,
        retry_conditions: collections.abc.Iterable[builtins.str] | None = ...,
        per_try_timeout: global___ComputeUrlMapXPathMatcherXDefaultRouteActionXRetryPolicyXPerTryTimeout | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["per_try_timeout", b"per_try_timeout"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["num_retries", b"num_retries", "per_try_timeout", b"per_try_timeout", "retry_conditions", b"retry_conditions"]) -> None: ...

global___ComputeUrlMapXPathMatcherXDefaultRouteActionXRetryPolicy = ComputeUrlMapXPathMatcherXDefaultRouteActionXRetryPolicy

@typing_extensions.final
class ComputeUrlMapXPathMatcherXDefaultRouteActionXTimeout(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NANOS_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    nanos: builtins.float
    seconds: builtins.str
    def __init__(
        self,
        *,
        nanos: builtins.float = ...,
        seconds: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nanos", b"nanos", "seconds", b"seconds"]) -> None: ...

global___ComputeUrlMapXPathMatcherXDefaultRouteActionXTimeout = ComputeUrlMapXPathMatcherXDefaultRouteActionXTimeout

@typing_extensions.final
class ComputeUrlMapXPathMatcherXDefaultRouteActionXUrlRewrite(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REWRITE_FIELD_NUMBER: builtins.int
    PATH_PREFIX_REWRITE_FIELD_NUMBER: builtins.int
    host_rewrite: builtins.str
    path_prefix_rewrite: builtins.str
    def __init__(
        self,
        *,
        host_rewrite: builtins.str = ...,
        path_prefix_rewrite: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host_rewrite", b"host_rewrite", "path_prefix_rewrite", b"path_prefix_rewrite"]) -> None: ...

global___ComputeUrlMapXPathMatcherXDefaultRouteActionXUrlRewrite = ComputeUrlMapXPathMatcherXDefaultRouteActionXUrlRewrite

@typing_extensions.final
class ComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_NAME_FIELD_NUMBER: builtins.int
    HEADER_VALUE_FIELD_NUMBER: builtins.int
    REPLACE_FIELD_NUMBER: builtins.int
    header_name: builtins.str
    header_value: builtins.str
    replace: builtins.bool
    def __init__(
        self,
        *,
        header_name: builtins.str = ...,
        header_value: builtins.str = ...,
        replace: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["header_name", b"header_name", "header_value", b"header_value", "replace", b"replace"]) -> None: ...

global___ComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd = ComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd

@typing_extensions.final
class ComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_NAME_FIELD_NUMBER: builtins.int
    HEADER_VALUE_FIELD_NUMBER: builtins.int
    REPLACE_FIELD_NUMBER: builtins.int
    header_name: builtins.str
    header_value: builtins.str
    replace: builtins.bool
    def __init__(
        self,
        *,
        header_name: builtins.str = ...,
        header_value: builtins.str = ...,
        replace: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["header_name", b"header_name", "header_value", b"header_value", "replace", b"replace"]) -> None: ...

global___ComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd = ComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd

@typing_extensions.final
class ComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServicesXHeaderAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_HEADERS_TO_REMOVE_FIELD_NUMBER: builtins.int
    RESPONSE_HEADERS_TO_REMOVE_FIELD_NUMBER: builtins.int
    REQUEST_HEADERS_TO_ADD_FIELD_NUMBER: builtins.int
    RESPONSE_HEADERS_TO_ADD_FIELD_NUMBER: builtins.int
    @property
    def request_headers_to_remove(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def response_headers_to_remove(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def request_headers_to_add(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd]: ...
    @property
    def response_headers_to_add(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd]: ...
    def __init__(
        self,
        *,
        request_headers_to_remove: collections.abc.Iterable[builtins.str] | None = ...,
        response_headers_to_remove: collections.abc.Iterable[builtins.str] | None = ...,
        request_headers_to_add: collections.abc.Iterable[global___ComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd] | None = ...,
        response_headers_to_add: collections.abc.Iterable[global___ComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["request_headers_to_add", b"request_headers_to_add", "request_headers_to_remove", b"request_headers_to_remove", "response_headers_to_add", b"response_headers_to_add", "response_headers_to_remove", b"response_headers_to_remove"]) -> None: ...

global___ComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServicesXHeaderAction = ComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServicesXHeaderAction

@typing_extensions.final
class ComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServices(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_SERVICE_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    HEADER_ACTION_FIELD_NUMBER: builtins.int
    backend_service: builtins.str
    weight: builtins.float
    @property
    def header_action(self) -> global___ComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServicesXHeaderAction: ...
    def __init__(
        self,
        *,
        backend_service: builtins.str = ...,
        weight: builtins.float = ...,
        header_action: global___ComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServicesXHeaderAction | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["header_action", b"header_action"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backend_service", b"backend_service", "header_action", b"header_action", "weight", b"weight"]) -> None: ...

global___ComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServices = ComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServices

@typing_extensions.final
class ComputeUrlMapXPathMatcherXDefaultRouteAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CORS_POLICY_FIELD_NUMBER: builtins.int
    FAULT_INJECTION_POLICY_FIELD_NUMBER: builtins.int
    REQUEST_MIRROR_POLICY_FIELD_NUMBER: builtins.int
    RETRY_POLICY_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    URL_REWRITE_FIELD_NUMBER: builtins.int
    WEIGHTED_BACKEND_SERVICES_FIELD_NUMBER: builtins.int
    @property
    def cors_policy(self) -> global___ComputeUrlMapXPathMatcherXDefaultRouteActionXCorsPolicy: ...
    @property
    def fault_injection_policy(self) -> global___ComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicy: ...
    @property
    def request_mirror_policy(self) -> global___ComputeUrlMapXPathMatcherXDefaultRouteActionXRequestMirrorPolicy: ...
    @property
    def retry_policy(self) -> global___ComputeUrlMapXPathMatcherXDefaultRouteActionXRetryPolicy: ...
    @property
    def timeout(self) -> global___ComputeUrlMapXPathMatcherXDefaultRouteActionXTimeout: ...
    @property
    def url_rewrite(self) -> global___ComputeUrlMapXPathMatcherXDefaultRouteActionXUrlRewrite: ...
    @property
    def weighted_backend_services(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServices]: ...
    def __init__(
        self,
        *,
        cors_policy: global___ComputeUrlMapXPathMatcherXDefaultRouteActionXCorsPolicy | None = ...,
        fault_injection_policy: global___ComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicy | None = ...,
        request_mirror_policy: global___ComputeUrlMapXPathMatcherXDefaultRouteActionXRequestMirrorPolicy | None = ...,
        retry_policy: global___ComputeUrlMapXPathMatcherXDefaultRouteActionXRetryPolicy | None = ...,
        timeout: global___ComputeUrlMapXPathMatcherXDefaultRouteActionXTimeout | None = ...,
        url_rewrite: global___ComputeUrlMapXPathMatcherXDefaultRouteActionXUrlRewrite | None = ...,
        weighted_backend_services: collections.abc.Iterable[global___ComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServices] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cors_policy", b"cors_policy", "fault_injection_policy", b"fault_injection_policy", "request_mirror_policy", b"request_mirror_policy", "retry_policy", b"retry_policy", "timeout", b"timeout", "url_rewrite", b"url_rewrite"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cors_policy", b"cors_policy", "fault_injection_policy", b"fault_injection_policy", "request_mirror_policy", b"request_mirror_policy", "retry_policy", b"retry_policy", "timeout", b"timeout", "url_rewrite", b"url_rewrite", "weighted_backend_services", b"weighted_backend_services"]) -> None: ...

global___ComputeUrlMapXPathMatcherXDefaultRouteAction = ComputeUrlMapXPathMatcherXDefaultRouteAction

@typing_extensions.final
class ComputeUrlMapXPathMatcherXDefaultUrlRedirect(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REDIRECT_FIELD_NUMBER: builtins.int
    HTTPS_REDIRECT_FIELD_NUMBER: builtins.int
    PATH_REDIRECT_FIELD_NUMBER: builtins.int
    PREFIX_REDIRECT_FIELD_NUMBER: builtins.int
    REDIRECT_RESPONSE_CODE_FIELD_NUMBER: builtins.int
    STRIP_QUERY_FIELD_NUMBER: builtins.int
    host_redirect: builtins.str
    https_redirect: builtins.bool
    path_redirect: builtins.str
    prefix_redirect: builtins.str
    redirect_response_code: builtins.str
    strip_query: builtins.bool
    def __init__(
        self,
        *,
        host_redirect: builtins.str = ...,
        https_redirect: builtins.bool = ...,
        path_redirect: builtins.str = ...,
        prefix_redirect: builtins.str = ...,
        redirect_response_code: builtins.str = ...,
        strip_query: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host_redirect", b"host_redirect", "https_redirect", b"https_redirect", "path_redirect", b"path_redirect", "prefix_redirect", b"prefix_redirect", "redirect_response_code", b"redirect_response_code", "strip_query", b"strip_query"]) -> None: ...

global___ComputeUrlMapXPathMatcherXDefaultUrlRedirect = ComputeUrlMapXPathMatcherXDefaultUrlRedirect

@typing_extensions.final
class ComputeUrlMapXPathMatcherXHeaderActionXRequestHeadersToAdd(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_NAME_FIELD_NUMBER: builtins.int
    HEADER_VALUE_FIELD_NUMBER: builtins.int
    REPLACE_FIELD_NUMBER: builtins.int
    header_name: builtins.str
    header_value: builtins.str
    replace: builtins.bool
    def __init__(
        self,
        *,
        header_name: builtins.str = ...,
        header_value: builtins.str = ...,
        replace: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["header_name", b"header_name", "header_value", b"header_value", "replace", b"replace"]) -> None: ...

global___ComputeUrlMapXPathMatcherXHeaderActionXRequestHeadersToAdd = ComputeUrlMapXPathMatcherXHeaderActionXRequestHeadersToAdd

@typing_extensions.final
class ComputeUrlMapXPathMatcherXHeaderActionXResponseHeadersToAdd(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_NAME_FIELD_NUMBER: builtins.int
    HEADER_VALUE_FIELD_NUMBER: builtins.int
    REPLACE_FIELD_NUMBER: builtins.int
    header_name: builtins.str
    header_value: builtins.str
    replace: builtins.bool
    def __init__(
        self,
        *,
        header_name: builtins.str = ...,
        header_value: builtins.str = ...,
        replace: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["header_name", b"header_name", "header_value", b"header_value", "replace", b"replace"]) -> None: ...

global___ComputeUrlMapXPathMatcherXHeaderActionXResponseHeadersToAdd = ComputeUrlMapXPathMatcherXHeaderActionXResponseHeadersToAdd

@typing_extensions.final
class ComputeUrlMapXPathMatcherXHeaderAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_HEADERS_TO_REMOVE_FIELD_NUMBER: builtins.int
    RESPONSE_HEADERS_TO_REMOVE_FIELD_NUMBER: builtins.int
    REQUEST_HEADERS_TO_ADD_FIELD_NUMBER: builtins.int
    RESPONSE_HEADERS_TO_ADD_FIELD_NUMBER: builtins.int
    @property
    def request_headers_to_remove(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def response_headers_to_remove(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def request_headers_to_add(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeUrlMapXPathMatcherXHeaderActionXRequestHeadersToAdd]: ...
    @property
    def response_headers_to_add(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeUrlMapXPathMatcherXHeaderActionXResponseHeadersToAdd]: ...
    def __init__(
        self,
        *,
        request_headers_to_remove: collections.abc.Iterable[builtins.str] | None = ...,
        response_headers_to_remove: collections.abc.Iterable[builtins.str] | None = ...,
        request_headers_to_add: collections.abc.Iterable[global___ComputeUrlMapXPathMatcherXHeaderActionXRequestHeadersToAdd] | None = ...,
        response_headers_to_add: collections.abc.Iterable[global___ComputeUrlMapXPathMatcherXHeaderActionXResponseHeadersToAdd] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["request_headers_to_add", b"request_headers_to_add", "request_headers_to_remove", b"request_headers_to_remove", "response_headers_to_add", b"response_headers_to_add", "response_headers_to_remove", b"response_headers_to_remove"]) -> None: ...

global___ComputeUrlMapXPathMatcherXHeaderAction = ComputeUrlMapXPathMatcherXHeaderAction

@typing_extensions.final
class ComputeUrlMapXPathMatcherXPathRuleXRouteActionXCorsPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_CREDENTIALS_FIELD_NUMBER: builtins.int
    ALLOW_HEADERS_FIELD_NUMBER: builtins.int
    ALLOW_METHODS_FIELD_NUMBER: builtins.int
    ALLOW_ORIGIN_REGEXES_FIELD_NUMBER: builtins.int
    ALLOW_ORIGINS_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    EXPOSE_HEADERS_FIELD_NUMBER: builtins.int
    MAX_AGE_FIELD_NUMBER: builtins.int
    allow_credentials: builtins.bool
    @property
    def allow_headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def allow_methods(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def allow_origin_regexes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def allow_origins(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    disabled: builtins.bool
    @property
    def expose_headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    max_age: builtins.float
    def __init__(
        self,
        *,
        allow_credentials: builtins.bool = ...,
        allow_headers: collections.abc.Iterable[builtins.str] | None = ...,
        allow_methods: collections.abc.Iterable[builtins.str] | None = ...,
        allow_origin_regexes: collections.abc.Iterable[builtins.str] | None = ...,
        allow_origins: collections.abc.Iterable[builtins.str] | None = ...,
        disabled: builtins.bool = ...,
        expose_headers: collections.abc.Iterable[builtins.str] | None = ...,
        max_age: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_credentials", b"allow_credentials", "allow_headers", b"allow_headers", "allow_methods", b"allow_methods", "allow_origin_regexes", b"allow_origin_regexes", "allow_origins", b"allow_origins", "disabled", b"disabled", "expose_headers", b"expose_headers", "max_age", b"max_age"]) -> None: ...

global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXCorsPolicy = ComputeUrlMapXPathMatcherXPathRuleXRouteActionXCorsPolicy

@typing_extensions.final
class ComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXAbort(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_STATUS_FIELD_NUMBER: builtins.int
    PERCENTAGE_FIELD_NUMBER: builtins.int
    http_status: builtins.float
    percentage: builtins.float
    def __init__(
        self,
        *,
        http_status: builtins.float = ...,
        percentage: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["http_status", b"http_status", "percentage", b"percentage"]) -> None: ...

global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXAbort = ComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXAbort

@typing_extensions.final
class ComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXDelayXFixedDelay(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NANOS_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    nanos: builtins.float
    seconds: builtins.str
    def __init__(
        self,
        *,
        nanos: builtins.float = ...,
        seconds: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nanos", b"nanos", "seconds", b"seconds"]) -> None: ...

global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXDelayXFixedDelay = ComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXDelayXFixedDelay

@typing_extensions.final
class ComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXDelay(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PERCENTAGE_FIELD_NUMBER: builtins.int
    FIXED_DELAY_FIELD_NUMBER: builtins.int
    percentage: builtins.float
    @property
    def fixed_delay(self) -> global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXDelayXFixedDelay: ...
    def __init__(
        self,
        *,
        percentage: builtins.float = ...,
        fixed_delay: global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXDelayXFixedDelay | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fixed_delay", b"fixed_delay"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fixed_delay", b"fixed_delay", "percentage", b"percentage"]) -> None: ...

global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXDelay = ComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXDelay

@typing_extensions.final
class ComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ABORT_FIELD_NUMBER: builtins.int
    DELAY_FIELD_NUMBER: builtins.int
    @property
    def abort(self) -> global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXAbort: ...
    @property
    def delay(self) -> global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXDelay: ...
    def __init__(
        self,
        *,
        abort: global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXAbort | None = ...,
        delay: global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXDelay | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["abort", b"abort", "delay", b"delay"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["abort", b"abort", "delay", b"delay"]) -> None: ...

global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicy = ComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicy

@typing_extensions.final
class ComputeUrlMapXPathMatcherXPathRuleXRouteActionXRequestMirrorPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_SERVICE_FIELD_NUMBER: builtins.int
    backend_service: builtins.str
    def __init__(
        self,
        *,
        backend_service: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["backend_service", b"backend_service"]) -> None: ...

global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXRequestMirrorPolicy = ComputeUrlMapXPathMatcherXPathRuleXRouteActionXRequestMirrorPolicy

@typing_extensions.final
class ComputeUrlMapXPathMatcherXPathRuleXRouteActionXRetryPolicyXPerTryTimeout(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NANOS_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    nanos: builtins.float
    seconds: builtins.str
    def __init__(
        self,
        *,
        nanos: builtins.float = ...,
        seconds: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nanos", b"nanos", "seconds", b"seconds"]) -> None: ...

global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXRetryPolicyXPerTryTimeout = ComputeUrlMapXPathMatcherXPathRuleXRouteActionXRetryPolicyXPerTryTimeout

@typing_extensions.final
class ComputeUrlMapXPathMatcherXPathRuleXRouteActionXRetryPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUM_RETRIES_FIELD_NUMBER: builtins.int
    RETRY_CONDITIONS_FIELD_NUMBER: builtins.int
    PER_TRY_TIMEOUT_FIELD_NUMBER: builtins.int
    num_retries: builtins.float
    @property
    def retry_conditions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def per_try_timeout(self) -> global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXRetryPolicyXPerTryTimeout: ...
    def __init__(
        self,
        *,
        num_retries: builtins.float = ...,
        retry_conditions: collections.abc.Iterable[builtins.str] | None = ...,
        per_try_timeout: global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXRetryPolicyXPerTryTimeout | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["per_try_timeout", b"per_try_timeout"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["num_retries", b"num_retries", "per_try_timeout", b"per_try_timeout", "retry_conditions", b"retry_conditions"]) -> None: ...

global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXRetryPolicy = ComputeUrlMapXPathMatcherXPathRuleXRouteActionXRetryPolicy

@typing_extensions.final
class ComputeUrlMapXPathMatcherXPathRuleXRouteActionXTimeout(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NANOS_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    nanos: builtins.float
    seconds: builtins.str
    def __init__(
        self,
        *,
        nanos: builtins.float = ...,
        seconds: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nanos", b"nanos", "seconds", b"seconds"]) -> None: ...

global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXTimeout = ComputeUrlMapXPathMatcherXPathRuleXRouteActionXTimeout

@typing_extensions.final
class ComputeUrlMapXPathMatcherXPathRuleXRouteActionXUrlRewrite(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REWRITE_FIELD_NUMBER: builtins.int
    PATH_PREFIX_REWRITE_FIELD_NUMBER: builtins.int
    host_rewrite: builtins.str
    path_prefix_rewrite: builtins.str
    def __init__(
        self,
        *,
        host_rewrite: builtins.str = ...,
        path_prefix_rewrite: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host_rewrite", b"host_rewrite", "path_prefix_rewrite", b"path_prefix_rewrite"]) -> None: ...

global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXUrlRewrite = ComputeUrlMapXPathMatcherXPathRuleXRouteActionXUrlRewrite

@typing_extensions.final
class ComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_NAME_FIELD_NUMBER: builtins.int
    HEADER_VALUE_FIELD_NUMBER: builtins.int
    REPLACE_FIELD_NUMBER: builtins.int
    header_name: builtins.str
    header_value: builtins.str
    replace: builtins.bool
    def __init__(
        self,
        *,
        header_name: builtins.str = ...,
        header_value: builtins.str = ...,
        replace: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["header_name", b"header_name", "header_value", b"header_value", "replace", b"replace"]) -> None: ...

global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd = ComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd

@typing_extensions.final
class ComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_NAME_FIELD_NUMBER: builtins.int
    HEADER_VALUE_FIELD_NUMBER: builtins.int
    REPLACE_FIELD_NUMBER: builtins.int
    header_name: builtins.str
    header_value: builtins.str
    replace: builtins.bool
    def __init__(
        self,
        *,
        header_name: builtins.str = ...,
        header_value: builtins.str = ...,
        replace: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["header_name", b"header_name", "header_value", b"header_value", "replace", b"replace"]) -> None: ...

global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd = ComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd

@typing_extensions.final
class ComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_HEADERS_TO_REMOVE_FIELD_NUMBER: builtins.int
    RESPONSE_HEADERS_TO_REMOVE_FIELD_NUMBER: builtins.int
    REQUEST_HEADERS_TO_ADD_FIELD_NUMBER: builtins.int
    RESPONSE_HEADERS_TO_ADD_FIELD_NUMBER: builtins.int
    @property
    def request_headers_to_remove(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def response_headers_to_remove(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def request_headers_to_add(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd]: ...
    @property
    def response_headers_to_add(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd]: ...
    def __init__(
        self,
        *,
        request_headers_to_remove: collections.abc.Iterable[builtins.str] | None = ...,
        response_headers_to_remove: collections.abc.Iterable[builtins.str] | None = ...,
        request_headers_to_add: collections.abc.Iterable[global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd] | None = ...,
        response_headers_to_add: collections.abc.Iterable[global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["request_headers_to_add", b"request_headers_to_add", "request_headers_to_remove", b"request_headers_to_remove", "response_headers_to_add", b"response_headers_to_add", "response_headers_to_remove", b"response_headers_to_remove"]) -> None: ...

global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderAction = ComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderAction

@typing_extensions.final
class ComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServices(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_SERVICE_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    HEADER_ACTION_FIELD_NUMBER: builtins.int
    backend_service: builtins.str
    weight: builtins.float
    @property
    def header_action(self) -> global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderAction: ...
    def __init__(
        self,
        *,
        backend_service: builtins.str = ...,
        weight: builtins.float = ...,
        header_action: global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderAction | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["header_action", b"header_action"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backend_service", b"backend_service", "header_action", b"header_action", "weight", b"weight"]) -> None: ...

global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServices = ComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServices

@typing_extensions.final
class ComputeUrlMapXPathMatcherXPathRuleXRouteAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CORS_POLICY_FIELD_NUMBER: builtins.int
    FAULT_INJECTION_POLICY_FIELD_NUMBER: builtins.int
    REQUEST_MIRROR_POLICY_FIELD_NUMBER: builtins.int
    RETRY_POLICY_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    URL_REWRITE_FIELD_NUMBER: builtins.int
    WEIGHTED_BACKEND_SERVICES_FIELD_NUMBER: builtins.int
    @property
    def cors_policy(self) -> global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXCorsPolicy: ...
    @property
    def fault_injection_policy(self) -> global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicy: ...
    @property
    def request_mirror_policy(self) -> global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXRequestMirrorPolicy: ...
    @property
    def retry_policy(self) -> global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXRetryPolicy: ...
    @property
    def timeout(self) -> global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXTimeout: ...
    @property
    def url_rewrite(self) -> global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXUrlRewrite: ...
    @property
    def weighted_backend_services(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServices]: ...
    def __init__(
        self,
        *,
        cors_policy: global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXCorsPolicy | None = ...,
        fault_injection_policy: global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicy | None = ...,
        request_mirror_policy: global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXRequestMirrorPolicy | None = ...,
        retry_policy: global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXRetryPolicy | None = ...,
        timeout: global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXTimeout | None = ...,
        url_rewrite: global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXUrlRewrite | None = ...,
        weighted_backend_services: collections.abc.Iterable[global___ComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServices] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cors_policy", b"cors_policy", "fault_injection_policy", b"fault_injection_policy", "request_mirror_policy", b"request_mirror_policy", "retry_policy", b"retry_policy", "timeout", b"timeout", "url_rewrite", b"url_rewrite"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cors_policy", b"cors_policy", "fault_injection_policy", b"fault_injection_policy", "request_mirror_policy", b"request_mirror_policy", "retry_policy", b"retry_policy", "timeout", b"timeout", "url_rewrite", b"url_rewrite", "weighted_backend_services", b"weighted_backend_services"]) -> None: ...

global___ComputeUrlMapXPathMatcherXPathRuleXRouteAction = ComputeUrlMapXPathMatcherXPathRuleXRouteAction

@typing_extensions.final
class ComputeUrlMapXPathMatcherXPathRuleXUrlRedirect(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REDIRECT_FIELD_NUMBER: builtins.int
    HTTPS_REDIRECT_FIELD_NUMBER: builtins.int
    PATH_REDIRECT_FIELD_NUMBER: builtins.int
    PREFIX_REDIRECT_FIELD_NUMBER: builtins.int
    REDIRECT_RESPONSE_CODE_FIELD_NUMBER: builtins.int
    STRIP_QUERY_FIELD_NUMBER: builtins.int
    host_redirect: builtins.str
    https_redirect: builtins.bool
    path_redirect: builtins.str
    prefix_redirect: builtins.str
    redirect_response_code: builtins.str
    strip_query: builtins.bool
    def __init__(
        self,
        *,
        host_redirect: builtins.str = ...,
        https_redirect: builtins.bool = ...,
        path_redirect: builtins.str = ...,
        prefix_redirect: builtins.str = ...,
        redirect_response_code: builtins.str = ...,
        strip_query: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host_redirect", b"host_redirect", "https_redirect", b"https_redirect", "path_redirect", b"path_redirect", "prefix_redirect", b"prefix_redirect", "redirect_response_code", b"redirect_response_code", "strip_query", b"strip_query"]) -> None: ...

global___ComputeUrlMapXPathMatcherXPathRuleXUrlRedirect = ComputeUrlMapXPathMatcherXPathRuleXUrlRedirect

@typing_extensions.final
class ComputeUrlMapXPathMatcherXPathRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATHS_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    ROUTE_ACTION_FIELD_NUMBER: builtins.int
    URL_REDIRECT_FIELD_NUMBER: builtins.int
    @property
    def paths(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    service: builtins.str
    @property
    def route_action(self) -> global___ComputeUrlMapXPathMatcherXPathRuleXRouteAction: ...
    @property
    def url_redirect(self) -> global___ComputeUrlMapXPathMatcherXPathRuleXUrlRedirect: ...
    def __init__(
        self,
        *,
        paths: collections.abc.Iterable[builtins.str] | None = ...,
        service: builtins.str = ...,
        route_action: global___ComputeUrlMapXPathMatcherXPathRuleXRouteAction | None = ...,
        url_redirect: global___ComputeUrlMapXPathMatcherXPathRuleXUrlRedirect | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["route_action", b"route_action", "url_redirect", b"url_redirect"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["paths", b"paths", "route_action", b"route_action", "service", b"service", "url_redirect", b"url_redirect"]) -> None: ...

global___ComputeUrlMapXPathMatcherXPathRule = ComputeUrlMapXPathMatcherXPathRule

@typing_extensions.final
class ComputeUrlMapXPathMatcherXRouteRulesXHeaderActionXRequestHeadersToAdd(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_NAME_FIELD_NUMBER: builtins.int
    HEADER_VALUE_FIELD_NUMBER: builtins.int
    REPLACE_FIELD_NUMBER: builtins.int
    header_name: builtins.str
    header_value: builtins.str
    replace: builtins.bool
    def __init__(
        self,
        *,
        header_name: builtins.str = ...,
        header_value: builtins.str = ...,
        replace: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["header_name", b"header_name", "header_value", b"header_value", "replace", b"replace"]) -> None: ...

global___ComputeUrlMapXPathMatcherXRouteRulesXHeaderActionXRequestHeadersToAdd = ComputeUrlMapXPathMatcherXRouteRulesXHeaderActionXRequestHeadersToAdd

@typing_extensions.final
class ComputeUrlMapXPathMatcherXRouteRulesXHeaderActionXResponseHeadersToAdd(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_NAME_FIELD_NUMBER: builtins.int
    HEADER_VALUE_FIELD_NUMBER: builtins.int
    REPLACE_FIELD_NUMBER: builtins.int
    header_name: builtins.str
    header_value: builtins.str
    replace: builtins.bool
    def __init__(
        self,
        *,
        header_name: builtins.str = ...,
        header_value: builtins.str = ...,
        replace: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["header_name", b"header_name", "header_value", b"header_value", "replace", b"replace"]) -> None: ...

global___ComputeUrlMapXPathMatcherXRouteRulesXHeaderActionXResponseHeadersToAdd = ComputeUrlMapXPathMatcherXRouteRulesXHeaderActionXResponseHeadersToAdd

@typing_extensions.final
class ComputeUrlMapXPathMatcherXRouteRulesXHeaderAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_HEADERS_TO_REMOVE_FIELD_NUMBER: builtins.int
    RESPONSE_HEADERS_TO_REMOVE_FIELD_NUMBER: builtins.int
    REQUEST_HEADERS_TO_ADD_FIELD_NUMBER: builtins.int
    RESPONSE_HEADERS_TO_ADD_FIELD_NUMBER: builtins.int
    @property
    def request_headers_to_remove(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def response_headers_to_remove(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def request_headers_to_add(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeUrlMapXPathMatcherXRouteRulesXHeaderActionXRequestHeadersToAdd]: ...
    @property
    def response_headers_to_add(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeUrlMapXPathMatcherXRouteRulesXHeaderActionXResponseHeadersToAdd]: ...
    def __init__(
        self,
        *,
        request_headers_to_remove: collections.abc.Iterable[builtins.str] | None = ...,
        response_headers_to_remove: collections.abc.Iterable[builtins.str] | None = ...,
        request_headers_to_add: collections.abc.Iterable[global___ComputeUrlMapXPathMatcherXRouteRulesXHeaderActionXRequestHeadersToAdd] | None = ...,
        response_headers_to_add: collections.abc.Iterable[global___ComputeUrlMapXPathMatcherXRouteRulesXHeaderActionXResponseHeadersToAdd] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["request_headers_to_add", b"request_headers_to_add", "request_headers_to_remove", b"request_headers_to_remove", "response_headers_to_add", b"response_headers_to_add", "response_headers_to_remove", b"response_headers_to_remove"]) -> None: ...

global___ComputeUrlMapXPathMatcherXRouteRulesXHeaderAction = ComputeUrlMapXPathMatcherXRouteRulesXHeaderAction

@typing_extensions.final
class ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXHeaderMatchesXRangeMatch(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RANGE_END_FIELD_NUMBER: builtins.int
    RANGE_START_FIELD_NUMBER: builtins.int
    range_end: builtins.float
    range_start: builtins.float
    def __init__(
        self,
        *,
        range_end: builtins.float = ...,
        range_start: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["range_end", b"range_end", "range_start", b"range_start"]) -> None: ...

global___ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXHeaderMatchesXRangeMatch = ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXHeaderMatchesXRangeMatch

@typing_extensions.final
class ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXHeaderMatches(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXACT_MATCH_FIELD_NUMBER: builtins.int
    HEADER_NAME_FIELD_NUMBER: builtins.int
    INVERT_MATCH_FIELD_NUMBER: builtins.int
    PREFIX_MATCH_FIELD_NUMBER: builtins.int
    PRESENT_MATCH_FIELD_NUMBER: builtins.int
    REGEX_MATCH_FIELD_NUMBER: builtins.int
    SUFFIX_MATCH_FIELD_NUMBER: builtins.int
    RANGE_MATCH_FIELD_NUMBER: builtins.int
    exact_match: builtins.str
    header_name: builtins.str
    invert_match: builtins.bool
    prefix_match: builtins.str
    present_match: builtins.bool
    regex_match: builtins.str
    suffix_match: builtins.str
    @property
    def range_match(self) -> global___ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXHeaderMatchesXRangeMatch: ...
    def __init__(
        self,
        *,
        exact_match: builtins.str = ...,
        header_name: builtins.str = ...,
        invert_match: builtins.bool = ...,
        prefix_match: builtins.str = ...,
        present_match: builtins.bool = ...,
        regex_match: builtins.str = ...,
        suffix_match: builtins.str = ...,
        range_match: global___ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXHeaderMatchesXRangeMatch | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["range_match", b"range_match"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["exact_match", b"exact_match", "header_name", b"header_name", "invert_match", b"invert_match", "prefix_match", b"prefix_match", "present_match", b"present_match", "range_match", b"range_match", "regex_match", b"regex_match", "suffix_match", b"suffix_match"]) -> None: ...

global___ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXHeaderMatches = ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXHeaderMatches

@typing_extensions.final
class ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXMetadataFiltersXFilterLabels(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    name: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "value", b"value"]) -> None: ...

global___ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXMetadataFiltersXFilterLabels = ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXMetadataFiltersXFilterLabels

@typing_extensions.final
class ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXMetadataFilters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILTER_MATCH_CRITERIA_FIELD_NUMBER: builtins.int
    FILTER_LABELS_FIELD_NUMBER: builtins.int
    filter_match_criteria: builtins.str
    @property
    def filter_labels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXMetadataFiltersXFilterLabels]: ...
    def __init__(
        self,
        *,
        filter_match_criteria: builtins.str = ...,
        filter_labels: collections.abc.Iterable[global___ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXMetadataFiltersXFilterLabels] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["filter_labels", b"filter_labels", "filter_match_criteria", b"filter_match_criteria"]) -> None: ...

global___ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXMetadataFilters = ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXMetadataFilters

@typing_extensions.final
class ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXQueryParameterMatches(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXACT_MATCH_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRESENT_MATCH_FIELD_NUMBER: builtins.int
    REGEX_MATCH_FIELD_NUMBER: builtins.int
    exact_match: builtins.str
    name: builtins.str
    present_match: builtins.bool
    regex_match: builtins.str
    def __init__(
        self,
        *,
        exact_match: builtins.str = ...,
        name: builtins.str = ...,
        present_match: builtins.bool = ...,
        regex_match: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["exact_match", b"exact_match", "name", b"name", "present_match", b"present_match", "regex_match", b"regex_match"]) -> None: ...

global___ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXQueryParameterMatches = ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXQueryParameterMatches

@typing_extensions.final
class ComputeUrlMapXPathMatcherXRouteRulesXMatchRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FULL_PATH_MATCH_FIELD_NUMBER: builtins.int
    IGNORE_CASE_FIELD_NUMBER: builtins.int
    PREFIX_MATCH_FIELD_NUMBER: builtins.int
    REGEX_MATCH_FIELD_NUMBER: builtins.int
    HEADER_MATCHES_FIELD_NUMBER: builtins.int
    METADATA_FILTERS_FIELD_NUMBER: builtins.int
    QUERY_PARAMETER_MATCHES_FIELD_NUMBER: builtins.int
    full_path_match: builtins.str
    ignore_case: builtins.bool
    prefix_match: builtins.str
    regex_match: builtins.str
    @property
    def header_matches(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXHeaderMatches]: ...
    @property
    def metadata_filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXMetadataFilters]: ...
    @property
    def query_parameter_matches(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXQueryParameterMatches]: ...
    def __init__(
        self,
        *,
        full_path_match: builtins.str = ...,
        ignore_case: builtins.bool = ...,
        prefix_match: builtins.str = ...,
        regex_match: builtins.str = ...,
        header_matches: collections.abc.Iterable[global___ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXHeaderMatches] | None = ...,
        metadata_filters: collections.abc.Iterable[global___ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXMetadataFilters] | None = ...,
        query_parameter_matches: collections.abc.Iterable[global___ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXQueryParameterMatches] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["full_path_match", b"full_path_match", "header_matches", b"header_matches", "ignore_case", b"ignore_case", "metadata_filters", b"metadata_filters", "prefix_match", b"prefix_match", "query_parameter_matches", b"query_parameter_matches", "regex_match", b"regex_match"]) -> None: ...

global___ComputeUrlMapXPathMatcherXRouteRulesXMatchRules = ComputeUrlMapXPathMatcherXRouteRulesXMatchRules

@typing_extensions.final
class ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXCorsPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_CREDENTIALS_FIELD_NUMBER: builtins.int
    ALLOW_HEADERS_FIELD_NUMBER: builtins.int
    ALLOW_METHODS_FIELD_NUMBER: builtins.int
    ALLOW_ORIGIN_REGEXES_FIELD_NUMBER: builtins.int
    ALLOW_ORIGINS_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    EXPOSE_HEADERS_FIELD_NUMBER: builtins.int
    MAX_AGE_FIELD_NUMBER: builtins.int
    allow_credentials: builtins.bool
    @property
    def allow_headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def allow_methods(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def allow_origin_regexes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def allow_origins(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    disabled: builtins.bool
    @property
    def expose_headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    max_age: builtins.float
    def __init__(
        self,
        *,
        allow_credentials: builtins.bool = ...,
        allow_headers: collections.abc.Iterable[builtins.str] | None = ...,
        allow_methods: collections.abc.Iterable[builtins.str] | None = ...,
        allow_origin_regexes: collections.abc.Iterable[builtins.str] | None = ...,
        allow_origins: collections.abc.Iterable[builtins.str] | None = ...,
        disabled: builtins.bool = ...,
        expose_headers: collections.abc.Iterable[builtins.str] | None = ...,
        max_age: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_credentials", b"allow_credentials", "allow_headers", b"allow_headers", "allow_methods", b"allow_methods", "allow_origin_regexes", b"allow_origin_regexes", "allow_origins", b"allow_origins", "disabled", b"disabled", "expose_headers", b"expose_headers", "max_age", b"max_age"]) -> None: ...

global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXCorsPolicy = ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXCorsPolicy

@typing_extensions.final
class ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXAbort(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_STATUS_FIELD_NUMBER: builtins.int
    PERCENTAGE_FIELD_NUMBER: builtins.int
    http_status: builtins.float
    percentage: builtins.float
    def __init__(
        self,
        *,
        http_status: builtins.float = ...,
        percentage: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["http_status", b"http_status", "percentage", b"percentage"]) -> None: ...

global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXAbort = ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXAbort

@typing_extensions.final
class ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXDelayXFixedDelay(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NANOS_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    nanos: builtins.float
    seconds: builtins.str
    def __init__(
        self,
        *,
        nanos: builtins.float = ...,
        seconds: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nanos", b"nanos", "seconds", b"seconds"]) -> None: ...

global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXDelayXFixedDelay = ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXDelayXFixedDelay

@typing_extensions.final
class ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXDelay(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PERCENTAGE_FIELD_NUMBER: builtins.int
    FIXED_DELAY_FIELD_NUMBER: builtins.int
    percentage: builtins.float
    @property
    def fixed_delay(self) -> global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXDelayXFixedDelay: ...
    def __init__(
        self,
        *,
        percentage: builtins.float = ...,
        fixed_delay: global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXDelayXFixedDelay | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fixed_delay", b"fixed_delay"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fixed_delay", b"fixed_delay", "percentage", b"percentage"]) -> None: ...

global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXDelay = ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXDelay

@typing_extensions.final
class ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ABORT_FIELD_NUMBER: builtins.int
    DELAY_FIELD_NUMBER: builtins.int
    @property
    def abort(self) -> global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXAbort: ...
    @property
    def delay(self) -> global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXDelay: ...
    def __init__(
        self,
        *,
        abort: global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXAbort | None = ...,
        delay: global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXDelay | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["abort", b"abort", "delay", b"delay"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["abort", b"abort", "delay", b"delay"]) -> None: ...

global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicy = ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicy

@typing_extensions.final
class ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXRequestMirrorPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_SERVICE_FIELD_NUMBER: builtins.int
    backend_service: builtins.str
    def __init__(
        self,
        *,
        backend_service: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["backend_service", b"backend_service"]) -> None: ...

global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXRequestMirrorPolicy = ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXRequestMirrorPolicy

@typing_extensions.final
class ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXRetryPolicyXPerTryTimeout(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NANOS_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    nanos: builtins.float
    seconds: builtins.str
    def __init__(
        self,
        *,
        nanos: builtins.float = ...,
        seconds: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nanos", b"nanos", "seconds", b"seconds"]) -> None: ...

global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXRetryPolicyXPerTryTimeout = ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXRetryPolicyXPerTryTimeout

@typing_extensions.final
class ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXRetryPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUM_RETRIES_FIELD_NUMBER: builtins.int
    RETRY_CONDITIONS_FIELD_NUMBER: builtins.int
    PER_TRY_TIMEOUT_FIELD_NUMBER: builtins.int
    num_retries: builtins.float
    @property
    def retry_conditions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def per_try_timeout(self) -> global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXRetryPolicyXPerTryTimeout: ...
    def __init__(
        self,
        *,
        num_retries: builtins.float = ...,
        retry_conditions: collections.abc.Iterable[builtins.str] | None = ...,
        per_try_timeout: global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXRetryPolicyXPerTryTimeout | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["per_try_timeout", b"per_try_timeout"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["num_retries", b"num_retries", "per_try_timeout", b"per_try_timeout", "retry_conditions", b"retry_conditions"]) -> None: ...

global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXRetryPolicy = ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXRetryPolicy

@typing_extensions.final
class ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXTimeout(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NANOS_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    nanos: builtins.float
    seconds: builtins.str
    def __init__(
        self,
        *,
        nanos: builtins.float = ...,
        seconds: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nanos", b"nanos", "seconds", b"seconds"]) -> None: ...

global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXTimeout = ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXTimeout

@typing_extensions.final
class ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXUrlRewrite(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REWRITE_FIELD_NUMBER: builtins.int
    PATH_PREFIX_REWRITE_FIELD_NUMBER: builtins.int
    host_rewrite: builtins.str
    path_prefix_rewrite: builtins.str
    def __init__(
        self,
        *,
        host_rewrite: builtins.str = ...,
        path_prefix_rewrite: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host_rewrite", b"host_rewrite", "path_prefix_rewrite", b"path_prefix_rewrite"]) -> None: ...

global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXUrlRewrite = ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXUrlRewrite

@typing_extensions.final
class ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_NAME_FIELD_NUMBER: builtins.int
    HEADER_VALUE_FIELD_NUMBER: builtins.int
    REPLACE_FIELD_NUMBER: builtins.int
    header_name: builtins.str
    header_value: builtins.str
    replace: builtins.bool
    def __init__(
        self,
        *,
        header_name: builtins.str = ...,
        header_value: builtins.str = ...,
        replace: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["header_name", b"header_name", "header_value", b"header_value", "replace", b"replace"]) -> None: ...

global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd = ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd

@typing_extensions.final
class ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_NAME_FIELD_NUMBER: builtins.int
    HEADER_VALUE_FIELD_NUMBER: builtins.int
    REPLACE_FIELD_NUMBER: builtins.int
    header_name: builtins.str
    header_value: builtins.str
    replace: builtins.bool
    def __init__(
        self,
        *,
        header_name: builtins.str = ...,
        header_value: builtins.str = ...,
        replace: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["header_name", b"header_name", "header_value", b"header_value", "replace", b"replace"]) -> None: ...

global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd = ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd

@typing_extensions.final
class ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_HEADERS_TO_REMOVE_FIELD_NUMBER: builtins.int
    RESPONSE_HEADERS_TO_REMOVE_FIELD_NUMBER: builtins.int
    REQUEST_HEADERS_TO_ADD_FIELD_NUMBER: builtins.int
    RESPONSE_HEADERS_TO_ADD_FIELD_NUMBER: builtins.int
    @property
    def request_headers_to_remove(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def response_headers_to_remove(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def request_headers_to_add(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd]: ...
    @property
    def response_headers_to_add(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd]: ...
    def __init__(
        self,
        *,
        request_headers_to_remove: collections.abc.Iterable[builtins.str] | None = ...,
        response_headers_to_remove: collections.abc.Iterable[builtins.str] | None = ...,
        request_headers_to_add: collections.abc.Iterable[global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd] | None = ...,
        response_headers_to_add: collections.abc.Iterable[global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["request_headers_to_add", b"request_headers_to_add", "request_headers_to_remove", b"request_headers_to_remove", "response_headers_to_add", b"response_headers_to_add", "response_headers_to_remove", b"response_headers_to_remove"]) -> None: ...

global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderAction = ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderAction

@typing_extensions.final
class ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServices(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_SERVICE_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    HEADER_ACTION_FIELD_NUMBER: builtins.int
    backend_service: builtins.str
    weight: builtins.float
    @property
    def header_action(self) -> global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderAction: ...
    def __init__(
        self,
        *,
        backend_service: builtins.str = ...,
        weight: builtins.float = ...,
        header_action: global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderAction | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["header_action", b"header_action"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backend_service", b"backend_service", "header_action", b"header_action", "weight", b"weight"]) -> None: ...

global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServices = ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServices

@typing_extensions.final
class ComputeUrlMapXPathMatcherXRouteRulesXRouteAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CORS_POLICY_FIELD_NUMBER: builtins.int
    FAULT_INJECTION_POLICY_FIELD_NUMBER: builtins.int
    REQUEST_MIRROR_POLICY_FIELD_NUMBER: builtins.int
    RETRY_POLICY_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    URL_REWRITE_FIELD_NUMBER: builtins.int
    WEIGHTED_BACKEND_SERVICES_FIELD_NUMBER: builtins.int
    @property
    def cors_policy(self) -> global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXCorsPolicy: ...
    @property
    def fault_injection_policy(self) -> global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicy: ...
    @property
    def request_mirror_policy(self) -> global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXRequestMirrorPolicy: ...
    @property
    def retry_policy(self) -> global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXRetryPolicy: ...
    @property
    def timeout(self) -> global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXTimeout: ...
    @property
    def url_rewrite(self) -> global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXUrlRewrite: ...
    @property
    def weighted_backend_services(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServices]: ...
    def __init__(
        self,
        *,
        cors_policy: global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXCorsPolicy | None = ...,
        fault_injection_policy: global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicy | None = ...,
        request_mirror_policy: global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXRequestMirrorPolicy | None = ...,
        retry_policy: global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXRetryPolicy | None = ...,
        timeout: global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXTimeout | None = ...,
        url_rewrite: global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXUrlRewrite | None = ...,
        weighted_backend_services: collections.abc.Iterable[global___ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServices] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cors_policy", b"cors_policy", "fault_injection_policy", b"fault_injection_policy", "request_mirror_policy", b"request_mirror_policy", "retry_policy", b"retry_policy", "timeout", b"timeout", "url_rewrite", b"url_rewrite"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cors_policy", b"cors_policy", "fault_injection_policy", b"fault_injection_policy", "request_mirror_policy", b"request_mirror_policy", "retry_policy", b"retry_policy", "timeout", b"timeout", "url_rewrite", b"url_rewrite", "weighted_backend_services", b"weighted_backend_services"]) -> None: ...

global___ComputeUrlMapXPathMatcherXRouteRulesXRouteAction = ComputeUrlMapXPathMatcherXRouteRulesXRouteAction

@typing_extensions.final
class ComputeUrlMapXPathMatcherXRouteRulesXUrlRedirect(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REDIRECT_FIELD_NUMBER: builtins.int
    HTTPS_REDIRECT_FIELD_NUMBER: builtins.int
    PATH_REDIRECT_FIELD_NUMBER: builtins.int
    PREFIX_REDIRECT_FIELD_NUMBER: builtins.int
    REDIRECT_RESPONSE_CODE_FIELD_NUMBER: builtins.int
    STRIP_QUERY_FIELD_NUMBER: builtins.int
    host_redirect: builtins.str
    https_redirect: builtins.bool
    path_redirect: builtins.str
    prefix_redirect: builtins.str
    redirect_response_code: builtins.str
    strip_query: builtins.bool
    def __init__(
        self,
        *,
        host_redirect: builtins.str = ...,
        https_redirect: builtins.bool = ...,
        path_redirect: builtins.str = ...,
        prefix_redirect: builtins.str = ...,
        redirect_response_code: builtins.str = ...,
        strip_query: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host_redirect", b"host_redirect", "https_redirect", b"https_redirect", "path_redirect", b"path_redirect", "prefix_redirect", b"prefix_redirect", "redirect_response_code", b"redirect_response_code", "strip_query", b"strip_query"]) -> None: ...

global___ComputeUrlMapXPathMatcherXRouteRulesXUrlRedirect = ComputeUrlMapXPathMatcherXRouteRulesXUrlRedirect

@typing_extensions.final
class ComputeUrlMapXPathMatcherXRouteRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIORITY_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    HEADER_ACTION_FIELD_NUMBER: builtins.int
    MATCH_RULES_FIELD_NUMBER: builtins.int
    ROUTE_ACTION_FIELD_NUMBER: builtins.int
    URL_REDIRECT_FIELD_NUMBER: builtins.int
    priority: builtins.float
    service: builtins.str
    @property
    def header_action(self) -> global___ComputeUrlMapXPathMatcherXRouteRulesXHeaderAction: ...
    @property
    def match_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeUrlMapXPathMatcherXRouteRulesXMatchRules]: ...
    @property
    def route_action(self) -> global___ComputeUrlMapXPathMatcherXRouteRulesXRouteAction: ...
    @property
    def url_redirect(self) -> global___ComputeUrlMapXPathMatcherXRouteRulesXUrlRedirect: ...
    def __init__(
        self,
        *,
        priority: builtins.float = ...,
        service: builtins.str = ...,
        header_action: global___ComputeUrlMapXPathMatcherXRouteRulesXHeaderAction | None = ...,
        match_rules: collections.abc.Iterable[global___ComputeUrlMapXPathMatcherXRouteRulesXMatchRules] | None = ...,
        route_action: global___ComputeUrlMapXPathMatcherXRouteRulesXRouteAction | None = ...,
        url_redirect: global___ComputeUrlMapXPathMatcherXRouteRulesXUrlRedirect | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["header_action", b"header_action", "route_action", b"route_action", "url_redirect", b"url_redirect"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["header_action", b"header_action", "match_rules", b"match_rules", "priority", b"priority", "route_action", b"route_action", "service", b"service", "url_redirect", b"url_redirect"]) -> None: ...

global___ComputeUrlMapXPathMatcherXRouteRules = ComputeUrlMapXPathMatcherXRouteRules

@typing_extensions.final
class ComputeUrlMapXPathMatcher(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_SERVICE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DEFAULT_ROUTE_ACTION_FIELD_NUMBER: builtins.int
    DEFAULT_URL_REDIRECT_FIELD_NUMBER: builtins.int
    HEADER_ACTION_FIELD_NUMBER: builtins.int
    PATH_RULE_FIELD_NUMBER: builtins.int
    ROUTE_RULES_FIELD_NUMBER: builtins.int
    default_service: builtins.str
    description: builtins.str
    name: builtins.str
    @property
    def default_route_action(self) -> global___ComputeUrlMapXPathMatcherXDefaultRouteAction: ...
    @property
    def default_url_redirect(self) -> global___ComputeUrlMapXPathMatcherXDefaultUrlRedirect: ...
    @property
    def header_action(self) -> global___ComputeUrlMapXPathMatcherXHeaderAction: ...
    @property
    def path_rule(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeUrlMapXPathMatcherXPathRule]: ...
    @property
    def route_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeUrlMapXPathMatcherXRouteRules]: ...
    def __init__(
        self,
        *,
        default_service: builtins.str = ...,
        description: builtins.str = ...,
        name: builtins.str = ...,
        default_route_action: global___ComputeUrlMapXPathMatcherXDefaultRouteAction | None = ...,
        default_url_redirect: global___ComputeUrlMapXPathMatcherXDefaultUrlRedirect | None = ...,
        header_action: global___ComputeUrlMapXPathMatcherXHeaderAction | None = ...,
        path_rule: collections.abc.Iterable[global___ComputeUrlMapXPathMatcherXPathRule] | None = ...,
        route_rules: collections.abc.Iterable[global___ComputeUrlMapXPathMatcherXRouteRules] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["default_route_action", b"default_route_action", "default_url_redirect", b"default_url_redirect", "header_action", b"header_action"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_route_action", b"default_route_action", "default_service", b"default_service", "default_url_redirect", b"default_url_redirect", "description", b"description", "header_action", b"header_action", "name", b"name", "path_rule", b"path_rule", "route_rules", b"route_rules"]) -> None: ...

global___ComputeUrlMapXPathMatcher = ComputeUrlMapXPathMatcher

@typing_extensions.final
class ComputeUrlMapXTest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    HOST_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    description: builtins.str
    host: builtins.str
    path: builtins.str
    service: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        host: builtins.str = ...,
        path: builtins.str = ...,
        service: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "host", b"host", "path", b"path", "service", b"service"]) -> None: ...

global___ComputeUrlMapXTest = ComputeUrlMapXTest

@typing_extensions.final
class ComputeUrlMapXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeUrlMapXTimeouts = ComputeUrlMapXTimeouts

@typing_extensions.final
class ComputeUrlMap(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DEFAULT_SERVICE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FINGERPRINT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MAP_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    DEFAULT_ROUTE_ACTION_FIELD_NUMBER: builtins.int
    DEFAULT_URL_REDIRECT_FIELD_NUMBER: builtins.int
    HEADER_ACTION_FIELD_NUMBER: builtins.int
    HOST_RULE_FIELD_NUMBER: builtins.int
    PATH_MATCHER_FIELD_NUMBER: builtins.int
    TEST_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    creation_timestamp: builtins.str
    default_service: builtins.str
    description: builtins.str
    fingerprint: builtins.str
    id: builtins.str
    map_id: builtins.float
    name: builtins.str
    project: builtins.str
    self_link: builtins.str
    @property
    def default_route_action(self) -> global___ComputeUrlMapXDefaultRouteAction: ...
    @property
    def default_url_redirect(self) -> global___ComputeUrlMapXDefaultUrlRedirect: ...
    @property
    def header_action(self) -> global___ComputeUrlMapXHeaderAction: ...
    @property
    def host_rule(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeUrlMapXHostRule]: ...
    @property
    def path_matcher(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeUrlMapXPathMatcher]: ...
    @property
    def test(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeUrlMapXTest]: ...
    @property
    def timeouts(self) -> global___ComputeUrlMapXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        creation_timestamp: builtins.str = ...,
        default_service: builtins.str = ...,
        description: builtins.str = ...,
        fingerprint: builtins.str = ...,
        id: builtins.str = ...,
        map_id: builtins.float = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        default_route_action: global___ComputeUrlMapXDefaultRouteAction | None = ...,
        default_url_redirect: global___ComputeUrlMapXDefaultUrlRedirect | None = ...,
        header_action: global___ComputeUrlMapXHeaderAction | None = ...,
        host_rule: collections.abc.Iterable[global___ComputeUrlMapXHostRule] | None = ...,
        path_matcher: collections.abc.Iterable[global___ComputeUrlMapXPathMatcher] | None = ...,
        test: collections.abc.Iterable[global___ComputeUrlMapXTest] | None = ...,
        timeouts: global___ComputeUrlMapXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["default_route_action", b"default_route_action", "default_url_redirect", b"default_url_redirect", "header_action", b"header_action", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "default_route_action", b"default_route_action", "default_service", b"default_service", "default_url_redirect", b"default_url_redirect", "description", b"description", "fingerprint", b"fingerprint", "header_action", b"header_action", "host_rule", b"host_rule", "id", b"id", "map_id", b"map_id", "name", b"name", "path_matcher", b"path_matcher", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "test", b"test", "timeouts", b"timeouts"]) -> None: ...

global___ComputeUrlMap = ComputeUrlMap



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CertificateDomainValidationOption(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DOMAIN_NAME_FIELD_NUMBER: builtins.int
    HOSTED_ZONE_ID_FIELD_NUMBER: builtins.int
    VALIDATION_DOMAIN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    domain_name: builtins.str
    hosted_zone_id: builtins.str
    validation_domain: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        domain_name: builtins.str = ...,
        hosted_zone_id: builtins.str = ...,
        validation_domain: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["domain_name", b"domain_name", "hosted_zone_id", b"hosted_zone_id", "resource_info", b"resource_info", "validation_domain", b"validation_domain"]) -> None: ...

global___CertificateDomainValidationOption = CertificateDomainValidationOption

@typing_extensions.final
class Certificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CERTIFICATE_AUTHORITY_ARN_FIELD_NUMBER: builtins.int
    CERTIFICATE_TRANSPARENCY_LOGGING_PREFERENCE_FIELD_NUMBER: builtins.int
    DOMAIN_NAME_FIELD_NUMBER: builtins.int
    DOMAIN_VALIDATION_OPTIONS_FIELD_NUMBER: builtins.int
    SUBJECT_ALTERNATIVE_NAMES_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    VALIDATION_METHOD_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    certificate_authority_arn: builtins.str
    certificate_transparency_logging_preference: builtins.str
    domain_name: builtins.str
    @property
    def domain_validation_options(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CertificateDomainValidationOption]: ...
    @property
    def subject_alternative_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    validation_method: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        certificate_authority_arn: builtins.str = ...,
        certificate_transparency_logging_preference: builtins.str = ...,
        domain_name: builtins.str = ...,
        domain_validation_options: collections.abc.Iterable[global___CertificateDomainValidationOption] | None = ...,
        subject_alternative_names: collections.abc.Iterable[builtins.str] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        validation_method: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate_authority_arn", b"certificate_authority_arn", "certificate_transparency_logging_preference", b"certificate_transparency_logging_preference", "domain_name", b"domain_name", "domain_validation_options", b"domain_validation_options", "resource_info", b"resource_info", "subject_alternative_names", b"subject_alternative_names", "tags", b"tags", "validation_method", b"validation_method"]) -> None: ...

global___Certificate = Certificate

@typing_extensions.final
class CertificateManager(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_FIELD_NUMBER: builtins.int
    @property
    def certificate(self) -> global___Certificate: ...
    def __init__(
        self,
        *,
        certificate: global___Certificate | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["certificate", b"certificate"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate", b"certificate"]) -> None: ...

global___CertificateManager = CertificateManager



from dataclasses import dataclass
from typing import List
from core.bp_metadata_utils.policy import Policy, Validation


@dataclass
class BlueprintMetaData:
    """
    Class to represent blueprint metadata
    """
    name: str
    desc: str
    author: str
    validations: List[Validation]



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class MicrosoftADVpcSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SUBNET_IDS_FIELD_NUMBER: builtins.int
    VPC_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    vpc_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
        vpc_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "subnet_ids", b"subnet_ids", "vpc_id", b"vpc_id"]) -> None: ...

global___MicrosoftADVpcSettings = MicrosoftADVpcSettings

@typing_extensions.final
class MicrosoftAD(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CREATE_ALIAS_FIELD_NUMBER: builtins.int
    EDITION_FIELD_NUMBER: builtins.int
    ENABLE_SSO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    SHORT_NAME_FIELD_NUMBER: builtins.int
    VPC_SETTINGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    create_alias: builtins.bool
    edition: builtins.str
    enable_sso: builtins.bool
    name: builtins.str
    password: builtins.str
    short_name: builtins.str
    @property
    def vpc_settings(self) -> global___MicrosoftADVpcSettings: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        create_alias: builtins.bool = ...,
        edition: builtins.str = ...,
        enable_sso: builtins.bool = ...,
        name: builtins.str = ...,
        password: builtins.str = ...,
        short_name: builtins.str = ...,
        vpc_settings: global___MicrosoftADVpcSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "vpc_settings", b"vpc_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_alias", b"create_alias", "edition", b"edition", "enable_sso", b"enable_sso", "name", b"name", "password", b"password", "resource_info", b"resource_info", "short_name", b"short_name", "vpc_settings", b"vpc_settings"]) -> None: ...

global___MicrosoftAD = MicrosoftAD

@typing_extensions.final
class DirectoryService(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MICROSOFT_AD_FIELD_NUMBER: builtins.int
    SIMPLE_AD_FIELD_NUMBER: builtins.int
    @property
    def microsoft_ad(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MicrosoftAD]: ...
    @property
    def simple_ad(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SimpleAD]: ...
    def __init__(
        self,
        *,
        microsoft_ad: collections.abc.Iterable[global___MicrosoftAD] | None = ...,
        simple_ad: collections.abc.Iterable[global___SimpleAD] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["microsoft_ad", b"microsoft_ad", "simple_ad", b"simple_ad"]) -> None: ...

global___DirectoryService = DirectoryService

@typing_extensions.final
class SimpleADVpcSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SUBNET_IDS_FIELD_NUMBER: builtins.int
    VPC_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    vpc_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
        vpc_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "subnet_ids", b"subnet_ids", "vpc_id", b"vpc_id"]) -> None: ...

global___SimpleADVpcSettings = SimpleADVpcSettings

@typing_extensions.final
class SimpleAD(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CREATE_ALIAS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ENABLE_SSO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    SHORT_NAME_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    VPC_SETTINGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    create_alias: builtins.bool
    description: builtins.str
    enable_sso: builtins.bool
    name: builtins.str
    password: builtins.str
    short_name: builtins.str
    size: builtins.str
    @property
    def vpc_settings(self) -> global___SimpleADVpcSettings: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        create_alias: builtins.bool = ...,
        description: builtins.str = ...,
        enable_sso: builtins.bool = ...,
        name: builtins.str = ...,
        password: builtins.str = ...,
        short_name: builtins.str = ...,
        size: builtins.str = ...,
        vpc_settings: global___SimpleADVpcSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "vpc_settings", b"vpc_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_alias", b"create_alias", "description", b"description", "enable_sso", b"enable_sso", "name", b"name", "password", b"password", "resource_info", b"resource_info", "short_name", b"short_name", "size", b"size", "vpc_settings", b"vpc_settings"]) -> None: ...

global___SimpleAD = SimpleAD
